yakumo.nova.v2.network.Manager

Package yakumo :: Package nova :: Package v2 :: Module network :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for networks in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for networks in Compute API v2

Instance Methods | [hide private]
yakumo.nova.v2.network.Resource |
create(self, bridge=`'``__UNDEF__``'`, bridge_interface=`'``__UNDEF__``'`, broadcast=`'``__UNDEF__``'`, cidr=`'``__UNDEF__``'`, cidr_v6=`'``__UNDEF__``'`, dhcp_server=`'``__UNDEF__``'`, dhcp_start=`'``__UNDEF__``'`, dns1=`'``__UNDEF__``'`, dns2=`'``__UNDEF__``'`, is_dhcp_enabled=`'``__UNDEF__``'`, gateway=`'``__UNDEF__``'`, gateway_v6=`'``__UNDEF__``'`, host=`'``__UNDEF__``'`, is_injected=`'``__UNDEF__``'`, name=`'``__UNDEF__``'`, mtu=`'``__UNDEF__``'`, is_multi_host=`'``__UNDEF__``'`, is_address_shared=`'``__UNDEF__``'`, netmask=`'``__UNDEF__``'`, netmask_v6=`'``__UNDEF__``'`, priority=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, rxtx_base=`'``__UNDEF__``'`, updated_at=`'``__UNDEF__``'`, vlan=`'``__UNDEF__``'`, vpn_private_address=`'``__UNDEF__``'`, vpn_public_address=`'``__UNDEF__``'`, vpn_public_port=`'``__UNDEF__``'`) Create a network | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``update``'``]``
| _json_resource_key = ``'``network``'``
| _json_resources_key = ``'``networks``'``
| _url_resource_path = ``'``/os-networks``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, bridge=`'``__UNDEF__``'`, bridge_interface=`'``__UNDEF__``'`, broadcast=`'``__UNDEF__``'`, cidr=`'``__UNDEF__``'`, cidr_v6=`'``__UNDEF__``'`, dhcp_server=`'``__UNDEF__``'`, dhcp_start=`'``__UNDEF__``'`, dns1=`'``__UNDEF__``'`, dns2=`'``__UNDEF__``'`, is_dhcp_enabled=`'``__UNDEF__``'`, gateway=`'``__UNDEF__``'`, gateway_v6=`'``__UNDEF__``'`, host=`'``__UNDEF__``'`, is_injected=`'``__UNDEF__``'`, name=`'``__UNDEF__``'`, mtu=`'``__UNDEF__``'`, is_multi_host=`'``__UNDEF__``'`, is_address_shared=`'``__UNDEF__``'`, netmask=`'``__UNDEF__``'`, netmask_v6=`'``__UNDEF__``'`, priority=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, rxtx_base=`'``__UNDEF__``'`, updated_at=`'``__UNDEF__``'`, vlan=`'``__UNDEF__``'`, vpn_private_address=`'``__UNDEF__``'`, vpn_public_address=`'``__UNDEF__``'`, vpn_public_port=`'``__UNDEF__``'`) | source code
Create a network Parameters: `bridge` (str) - VIFs on this network are connected to this bridge `bridge_interface` (str) - The bridge is connected to this interface `broadcast` (str) - The broadcast address `cidr` (str) - IPv4 subnet `cidr_v6` (str) - IPv6 subnet `dhcp_server` (str) - DHCP server address `dhcp_start` (str) - DHCP starting address `dns1` (str) - First DNS `dns2` (str) - Second DNS `is_dhcp_enabled` (str) - enable DHCP `is_injected` (str) - Injected flag `is_multi_host` (str) - Multi host `is_address_shared` (str) - Share Address `gateway` (str) - IPv4 gateway `gateway_v6` (str) - IPv6 gateway `host` (str) - Network host `mtu` (int) - MTU `name` (str) - Network label `netmask` (str) - IPv4 netmask `netmask_v6` (str) - IPv6 netmask `priority` (str) - Network priority `project` (yakumo.project.Resource) - Project `rxtx_base` (str) - RXTX base factor value for the network `vlan` (int) - VLAN ID `vpn_private_address` (str) - VPN private address `vpn_public_address` (str) - VPN public address `vpn_public_port` (int) - VPN public port Returns: yakumo.nova.v2.network.Resource Created network Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('bridge', 'bridge', mapper.Noop), ('bridg
      e_interface', 'bridge_interface', mapper.Noop), ('broadcast', 'broadca
      st', mapper.Noop), ('cidr', 'cidr', mapper.Noop), ('cidr_v6', 'cidr_v6
      ', mapper.Noop), ('dhcp_server', 'dhcp_server', mapper.Noop), ('dhcp_s
      tart', 'dhcp_start', mapper.Noop), ('dns1', 'dns1', mapper.Noop), ('dn
      s2', 'dns2', mapper.Noop), ('gateway', 'gateway', mapper.Noop), ('gate
      way_v6', 'gateway_v6', mapper.Noop), ('host', 'host', mapper.Noop), ('
      name', 'label', mapper.Noop), ('mtu', 'mtu', mapper.Noop), ('netmask',
      ...